# -*- coding: utf-8 -*-

"""
MIT License

Copyright (c) 2019 Arthurdw

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

class PythonaryException(Exception):
    """Base exception class for pythonary!

    This should catch all the pythonary errors! """
    pass

class UNKError(PythonaryException):
    """This should never pop as its for an unknown error, but when it does please report it to the developer!"""
    pass

class MissingCoreArguments(PythonaryException):
    """Exception caused when `app_id` or `app_key` is missing"""
    pass

class ApplicationError(PythonaryException):
    """Exception caused when not enough arguments are given or when the Application allowance has been reached.
    Likely user caused."""
    pass

class BadRequest(PythonaryException):
    """Exception caused when an internal 400 error occurs!"""
    pass

class NotFound(PythonaryException):
    """Exception caused when the word can't be found with the applying filters, or in its current state!
    Try putting the word in a singular format."""
    pass

class RequestToLong(PythonaryException):
    """Exception caused when the word is longer than 128 characters"""
    pass

class InternalError(PythonaryException):
    """This error should never occur, if it does contact Oxford Dictionaries:
    https://developer.oxforddictionaries.com/contact-us"""
    pass

class BadGateway(PythonaryException):
    """Exception caused when Oxford Dictionaries API is down or being upgraded"""
    pass

class ServiceUnavailable(PythonaryException):
    """Exception caused when Oxford Dictionaries API servers are up, but overloaded with requests.
    Please try again later."""
    pass

class GatewayTimeout(PythonaryException):
    """Exception caused when Oxford Dictionaries API servers are up, but the request couldn’t be serviced due to some failure within the stack of Oxford Dictionaries.
    Please try again later."""
    pass