# -*- coding: utf-8 -*-

"""
MIT License

Copyright (c) 2019 Arthurdw

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

import json, requests
from .errors import *

def get_Oxford(word=None, language='EN', app_id='Undefined', app_key='Undefined'):
    if word is None: raise ApplicationError(f"ERROR: 001 | No word was given!")
    else:
        url = "https://od-api.oxforddictionaries.com/api/v2/entries/" + language + "/" + str(word.lower())
        request = requests.get(url, headers = {"app_id": app_id, "app_key": app_key})
        if request.status_code == 504: raise GatewayTimeout("ERROR 504 | The Oxford Dictionaries API servers are up, but the request couldn’t be serviced due to some failure within the stack of Oxford Dictionaries. Please try again later.")
        elif request.status_code == 503: raise ServiceUnavailable("ERROR 503 | The Oxford Dictionaries API servers are up, but overloaded with requests. Please try again later.")
        elif request.status_code == 502: raise BadGateway("Oxford Dictionaries API is down or being upgraded.")
        elif request.status_code == 500: raise InternalError("ERROR 500 | Oh, this is weird... this error should never occur, please contact Oxford Dictionaries about this here: https://developer.oxforddictionaries.com/contact-us")
        elif request.status_code == 414: raise RequestToLong('ERROR 414 | The word [{}] exceeded the maximum character amount (128), please reduce the string and try again.'.format(word))
        elif request.status_code == 404: raise NotFound('ERROR 404 | Couldn\'t find the word {} with the applied filters!'.format(word))
        elif request.status_code == 403: raise ApplicationError("ERROR: 403 | The request failed due to invalid credentials, or you have reached your Application allowance.")
        elif request.status_code == 400: raise BadRequest('ERROR 400 | {}'.format(request.text))
        elif request.status_code == 200: return json.dumps(request.json())
        else: raise UNKError('ERROR 001 | An unknown error occurred while trying to execute the internal "get" function!')